/****************************************************************************
** Meta object code from reading C++ file 'qgamepadkeynavigation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qtgamepad-opensource-src-5.9.4/src/gamepad/qgamepadkeynavigation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgamepadkeynavigation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGamepadKeyNavigation_t {
    QByteArrayData data[66];
    char stringdata0[969];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGamepadKeyNavigation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGamepadKeyNavigation_t qt_meta_stringdata_QGamepadKeyNavigation = {
    {
QT_MOC_LITERAL(0, 0, 21), // "QGamepadKeyNavigation"
QT_MOC_LITERAL(1, 22, 13), // "activeChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 8), // "isActive"
QT_MOC_LITERAL(4, 46, 14), // "gamepadChanged"
QT_MOC_LITERAL(5, 61, 9), // "QGamepad*"
QT_MOC_LITERAL(6, 71, 7), // "gamepad"
QT_MOC_LITERAL(7, 79, 12), // "upKeyChanged"
QT_MOC_LITERAL(8, 92, 7), // "Qt::Key"
QT_MOC_LITERAL(9, 100, 3), // "key"
QT_MOC_LITERAL(10, 104, 14), // "downKeyChanged"
QT_MOC_LITERAL(11, 119, 14), // "leftKeyChanged"
QT_MOC_LITERAL(12, 134, 15), // "rightKeyChanged"
QT_MOC_LITERAL(13, 150, 17), // "buttonAKeyChanged"
QT_MOC_LITERAL(14, 168, 17), // "buttonBKeyChanged"
QT_MOC_LITERAL(15, 186, 17), // "buttonXKeyChanged"
QT_MOC_LITERAL(16, 204, 17), // "buttonYKeyChanged"
QT_MOC_LITERAL(17, 222, 22), // "buttonSelectKeyChanged"
QT_MOC_LITERAL(18, 245, 21), // "buttonStartKeyChanged"
QT_MOC_LITERAL(19, 267, 21), // "buttonGuideKeyChanged"
QT_MOC_LITERAL(20, 289, 18), // "buttonL1KeyChanged"
QT_MOC_LITERAL(21, 308, 18), // "buttonR1KeyChanged"
QT_MOC_LITERAL(22, 327, 18), // "buttonL2KeyChanged"
QT_MOC_LITERAL(23, 346, 18), // "buttonR2KeyChanged"
QT_MOC_LITERAL(24, 365, 18), // "buttonL3KeyChanged"
QT_MOC_LITERAL(25, 384, 18), // "buttonR3KeyChanged"
QT_MOC_LITERAL(26, 403, 9), // "setActive"
QT_MOC_LITERAL(27, 413, 10), // "setGamepad"
QT_MOC_LITERAL(28, 424, 8), // "setUpKey"
QT_MOC_LITERAL(29, 433, 10), // "setDownKey"
QT_MOC_LITERAL(30, 444, 10), // "setLeftKey"
QT_MOC_LITERAL(31, 455, 11), // "setRightKey"
QT_MOC_LITERAL(32, 467, 13), // "setButtonAKey"
QT_MOC_LITERAL(33, 481, 13), // "setButtonBKey"
QT_MOC_LITERAL(34, 495, 13), // "setButtonXKey"
QT_MOC_LITERAL(35, 509, 13), // "setButtonYKey"
QT_MOC_LITERAL(36, 523, 18), // "setButtonSelectKey"
QT_MOC_LITERAL(37, 542, 17), // "setButtonStartKey"
QT_MOC_LITERAL(38, 560, 17), // "setButtonGuideKey"
QT_MOC_LITERAL(39, 578, 14), // "setButtonL1Key"
QT_MOC_LITERAL(40, 593, 14), // "setButtonR1Key"
QT_MOC_LITERAL(41, 608, 14), // "setButtonL2Key"
QT_MOC_LITERAL(42, 623, 14), // "setButtonR2Key"
QT_MOC_LITERAL(43, 638, 14), // "setButtonL3Key"
QT_MOC_LITERAL(44, 653, 14), // "setButtonR3Key"
QT_MOC_LITERAL(45, 668, 33), // "_q_processGamepadButtonPressE..."
QT_MOC_LITERAL(46, 702, 30), // "QGamepadManager::GamepadButton"
QT_MOC_LITERAL(47, 733, 35), // "_q_processGamepadButtonReleas..."
QT_MOC_LITERAL(48, 769, 6), // "active"
QT_MOC_LITERAL(49, 776, 5), // "upKey"
QT_MOC_LITERAL(50, 782, 7), // "downKey"
QT_MOC_LITERAL(51, 790, 7), // "leftKey"
QT_MOC_LITERAL(52, 798, 8), // "rightKey"
QT_MOC_LITERAL(53, 807, 10), // "buttonAKey"
QT_MOC_LITERAL(54, 818, 10), // "buttonBKey"
QT_MOC_LITERAL(55, 829, 10), // "buttonXKey"
QT_MOC_LITERAL(56, 840, 10), // "buttonYKey"
QT_MOC_LITERAL(57, 851, 15), // "buttonSelectKey"
QT_MOC_LITERAL(58, 867, 14), // "buttonStartKey"
QT_MOC_LITERAL(59, 882, 14), // "buttonGuideKey"
QT_MOC_LITERAL(60, 897, 11), // "buttonL1Key"
QT_MOC_LITERAL(61, 909, 11), // "buttonR1Key"
QT_MOC_LITERAL(62, 921, 11), // "buttonL2Key"
QT_MOC_LITERAL(63, 933, 11), // "buttonR2Key"
QT_MOC_LITERAL(64, 945, 11), // "buttonL3Key"
QT_MOC_LITERAL(65, 957, 11) // "buttonR3Key"

    },
    "QGamepadKeyNavigation\0activeChanged\0"
    "\0isActive\0gamepadChanged\0QGamepad*\0"
    "gamepad\0upKeyChanged\0Qt::Key\0key\0"
    "downKeyChanged\0leftKeyChanged\0"
    "rightKeyChanged\0buttonAKeyChanged\0"
    "buttonBKeyChanged\0buttonXKeyChanged\0"
    "buttonYKeyChanged\0buttonSelectKeyChanged\0"
    "buttonStartKeyChanged\0buttonGuideKeyChanged\0"
    "buttonL1KeyChanged\0buttonR1KeyChanged\0"
    "buttonL2KeyChanged\0buttonR2KeyChanged\0"
    "buttonL3KeyChanged\0buttonR3KeyChanged\0"
    "setActive\0setGamepad\0setUpKey\0setDownKey\0"
    "setLeftKey\0setRightKey\0setButtonAKey\0"
    "setButtonBKey\0setButtonXKey\0setButtonYKey\0"
    "setButtonSelectKey\0setButtonStartKey\0"
    "setButtonGuideKey\0setButtonL1Key\0"
    "setButtonR1Key\0setButtonL2Key\0"
    "setButtonR2Key\0setButtonL3Key\0"
    "setButtonR3Key\0_q_processGamepadButtonPressEvent\0"
    "QGamepadManager::GamepadButton\0"
    "_q_processGamepadButtonReleaseEvent\0"
    "active\0upKey\0downKey\0leftKey\0rightKey\0"
    "buttonAKey\0buttonBKey\0buttonXKey\0"
    "buttonYKey\0buttonSelectKey\0buttonStartKey\0"
    "buttonGuideKey\0buttonL1Key\0buttonR1Key\0"
    "buttonL2Key\0buttonR2Key\0buttonL3Key\0"
    "buttonR3Key"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGamepadKeyNavigation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      40,   14, // methods
      19,  340, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      19,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  214,    2, 0x06 /* Public */,
       4,    1,  217,    2, 0x06 /* Public */,
       7,    1,  220,    2, 0x06 /* Public */,
      10,    1,  223,    2, 0x06 /* Public */,
      11,    1,  226,    2, 0x06 /* Public */,
      12,    1,  229,    2, 0x06 /* Public */,
      13,    1,  232,    2, 0x06 /* Public */,
      14,    1,  235,    2, 0x06 /* Public */,
      15,    1,  238,    2, 0x06 /* Public */,
      16,    1,  241,    2, 0x06 /* Public */,
      17,    1,  244,    2, 0x06 /* Public */,
      18,    1,  247,    2, 0x06 /* Public */,
      19,    1,  250,    2, 0x06 /* Public */,
      20,    1,  253,    2, 0x06 /* Public */,
      21,    1,  256,    2, 0x06 /* Public */,
      22,    1,  259,    2, 0x06 /* Public */,
      23,    1,  262,    2, 0x06 /* Public */,
      24,    1,  265,    2, 0x06 /* Public */,
      25,    1,  268,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      26,    1,  271,    2, 0x0a /* Public */,
      27,    1,  274,    2, 0x0a /* Public */,
      28,    1,  277,    2, 0x0a /* Public */,
      29,    1,  280,    2, 0x0a /* Public */,
      30,    1,  283,    2, 0x0a /* Public */,
      31,    1,  286,    2, 0x0a /* Public */,
      32,    1,  289,    2, 0x0a /* Public */,
      33,    1,  292,    2, 0x0a /* Public */,
      34,    1,  295,    2, 0x0a /* Public */,
      35,    1,  298,    2, 0x0a /* Public */,
      36,    1,  301,    2, 0x0a /* Public */,
      37,    1,  304,    2, 0x0a /* Public */,
      38,    1,  307,    2, 0x0a /* Public */,
      39,    1,  310,    2, 0x0a /* Public */,
      40,    1,  313,    2, 0x0a /* Public */,
      41,    1,  316,    2, 0x0a /* Public */,
      42,    1,  319,    2, 0x0a /* Public */,
      43,    1,  322,    2, 0x0a /* Public */,
      44,    1,  325,    2, 0x0a /* Public */,
      45,    3,  328,    2, 0x08 /* Private */,
      47,    2,  335,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 46, QMetaType::Double,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 46,    2,    2,

 // properties: name, type, flags
      48, QMetaType::Bool, 0x00495103,
       6, 0x80000000 | 5, 0x0049510b,
      49, 0x80000000 | 8, 0x0049510b,
      50, 0x80000000 | 8, 0x0049510b,
      51, 0x80000000 | 8, 0x0049510b,
      52, 0x80000000 | 8, 0x0049510b,
      53, 0x80000000 | 8, 0x0049510b,
      54, 0x80000000 | 8, 0x0049510b,
      55, 0x80000000 | 8, 0x0049510b,
      56, 0x80000000 | 8, 0x0049510b,
      57, 0x80000000 | 8, 0x0049510b,
      58, 0x80000000 | 8, 0x0049510b,
      59, 0x80000000 | 8, 0x0049510b,
      60, 0x80000000 | 8, 0x0049510b,
      61, 0x80000000 | 8, 0x0049510b,
      62, 0x80000000 | 8, 0x0049510b,
      63, 0x80000000 | 8, 0x0049510b,
      64, 0x80000000 | 8, 0x0049510b,
      65, 0x80000000 | 8, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,
      17,
      18,

       0        // eod
};

void QGamepadKeyNavigation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QGamepadKeyNavigation *_t = static_cast<QGamepadKeyNavigation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->gamepadChanged((*reinterpret_cast< QGamepad*(*)>(_a[1]))); break;
        case 2: _t->upKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 3: _t->downKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 4: _t->leftKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 5: _t->rightKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 6: _t->buttonAKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 7: _t->buttonBKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 8: _t->buttonXKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 9: _t->buttonYKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 10: _t->buttonSelectKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 11: _t->buttonStartKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 12: _t->buttonGuideKeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 13: _t->buttonL1KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 14: _t->buttonR1KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 15: _t->buttonL2KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 16: _t->buttonR2KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 17: _t->buttonL3KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 18: _t->buttonR3KeyChanged((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 19: _t->setActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->setGamepad((*reinterpret_cast< QGamepad*(*)>(_a[1]))); break;
        case 21: _t->setUpKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 22: _t->setDownKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 23: _t->setLeftKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 24: _t->setRightKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 25: _t->setButtonAKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 26: _t->setButtonBKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 27: _t->setButtonXKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 28: _t->setButtonYKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 29: _t->setButtonSelectKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 30: _t->setButtonStartKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 31: _t->setButtonGuideKey((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 32: _t->setButtonL1Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 33: _t->setButtonR1Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 34: _t->setButtonL2Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 35: _t->setButtonR2Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 36: _t->setButtonL3Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 37: _t->setButtonR3Key((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 38: _t->d_func()->_q_processGamepadButtonPressEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QGamepadManager::GamepadButton(*)>(_a[2])),(*reinterpret_cast< double(*)>(_a[3]))); break;
        case 39: _t->d_func()->_q_processGamepadButtonReleaseEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QGamepadManager::GamepadButton(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGamepadManager::GamepadButton >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGamepadManager::GamepadButton >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QGamepadKeyNavigation::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::activeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(QGamepad * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::gamepadChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::upKeyChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::downKeyChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::leftKeyChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::rightKeyChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonAKeyChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonBKeyChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonXKeyChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonYKeyChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonSelectKeyChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonStartKeyChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonGuideKeyChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonL1KeyChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonR1KeyChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonL2KeyChanged)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonR2KeyChanged)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonL3KeyChanged)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (QGamepadKeyNavigation::*_t)(Qt::Key );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGamepadKeyNavigation::buttonR3KeyChanged)) {
                *result = 18;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        QGamepadKeyNavigation *_t = static_cast<QGamepadKeyNavigation *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast< QGamepad**>(_v) = _t->gamepad(); break;
        case 2: *reinterpret_cast< Qt::Key*>(_v) = _t->upKey(); break;
        case 3: *reinterpret_cast< Qt::Key*>(_v) = _t->downKey(); break;
        case 4: *reinterpret_cast< Qt::Key*>(_v) = _t->leftKey(); break;
        case 5: *reinterpret_cast< Qt::Key*>(_v) = _t->rightKey(); break;
        case 6: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonAKey(); break;
        case 7: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonBKey(); break;
        case 8: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonXKey(); break;
        case 9: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonYKey(); break;
        case 10: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonSelectKey(); break;
        case 11: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonStartKey(); break;
        case 12: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonGuideKey(); break;
        case 13: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonL1Key(); break;
        case 14: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonR1Key(); break;
        case 15: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonL2Key(); break;
        case 16: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonR2Key(); break;
        case 17: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonL3Key(); break;
        case 18: *reinterpret_cast< Qt::Key*>(_v) = _t->buttonR3Key(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        QGamepadKeyNavigation *_t = static_cast<QGamepadKeyNavigation *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setGamepad(*reinterpret_cast< QGamepad**>(_v)); break;
        case 2: _t->setUpKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 3: _t->setDownKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 4: _t->setLeftKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 5: _t->setRightKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 6: _t->setButtonAKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 7: _t->setButtonBKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 8: _t->setButtonXKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 9: _t->setButtonYKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 10: _t->setButtonSelectKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 11: _t->setButtonStartKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 12: _t->setButtonGuideKey(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 13: _t->setButtonL1Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 14: _t->setButtonR1Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 15: _t->setButtonL2Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 16: _t->setButtonR2Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 17: _t->setButtonL3Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        case 18: _t->setButtonR3Key(*reinterpret_cast< Qt::Key*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject QGamepadKeyNavigation::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_QGamepadKeyNavigation.data,
      qt_meta_data_QGamepadKeyNavigation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QGamepadKeyNavigation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGamepadKeyNavigation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGamepadKeyNavigation.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QGamepadKeyNavigation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 19;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QGamepadKeyNavigation::activeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QGamepadKeyNavigation::gamepadChanged(QGamepad * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QGamepadKeyNavigation::upKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QGamepadKeyNavigation::downKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QGamepadKeyNavigation::leftKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QGamepadKeyNavigation::rightKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QGamepadKeyNavigation::buttonAKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QGamepadKeyNavigation::buttonBKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QGamepadKeyNavigation::buttonXKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QGamepadKeyNavigation::buttonYKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void QGamepadKeyNavigation::buttonSelectKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QGamepadKeyNavigation::buttonStartKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QGamepadKeyNavigation::buttonGuideKeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QGamepadKeyNavigation::buttonL1KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QGamepadKeyNavigation::buttonR1KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QGamepadKeyNavigation::buttonL2KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void QGamepadKeyNavigation::buttonR2KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void QGamepadKeyNavigation::buttonL3KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void QGamepadKeyNavigation::buttonR3KeyChanged(Qt::Key _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
